const path = require("path");
const fs = require("fs-extra");
const inquirer = require("inquirer");
const ejs = require("ejs");

module.exports = async function (name, options) {
  const cwd = process.cwd();
  const targetDir = path.join(cwd, name);

  if (fs.existsSync(targetDir)) {
    if (options && options.force) {
      await fs.remove(targetDir);
    } else {
      let { action } = await inquirer.prompt([
        {
          name: "action",
          type: "list",
          message: "Target directory already exists Pick an action:",
          choices: [
            {
              name: "Overwrite",
              value: "overwrite",
            },
            {
              name: "Cancel",
              value: false,
            },
          ],
        },
      ]);
      if (!action) {
        return;
      } else if (action === "overwrite") {
        console.log(`\r\nRemoving...`);
        await fs.remove(targetDir);
      }
    }
  }
  await fs.mkdir(targetDir);

  const destUrl = path.join(__dirname, "../templates");

  const copyFiles = (destUrl, targetDir) => {
    fs.readdir(destUrl, async (err, files) => {
      if (err) throw err;
      for (let file of files) {
        let currentPath = path.join(destUrl, file);
        let currentTargetPath = path.join(targetDir, file);
        if (fs.statSync(currentPath).isFile()) {
          ejs.renderFile(currentPath, { name }).then((data) => {
            fs.writeFileSync(currentTargetPath, data);
          });
          continue;
        }
        await fs.mkdir(currentTargetPath);
        copyFiles(currentPath, currentTargetPath);
      }
    });
  };

  copyFiles(destUrl, targetDir);
};
